@@ -1,9 +1,11 @@
 import cv2
 import numpy as np
 
-AREA_RATE = 0.7
+AREA_RATE = 0.6
 
 # 填充目标区域padding像素
+
+
 def padRect(image, box, padding):
     height, width, num = image.shape
 
@@ -67,22 +69,24 @@ def calcRect(image, box, padding=5, areaThreshold=900):
     # point4s = [(0, 0), (x1-x0, 0), (0, y1-y0), (x1-x0, y1-y0)]
 
     # # 寻找离四个顶点最近的矩形点
-    # tarPoints=[]
-    # radius=(x1-x0)/3
+    # tarPoints = []
+    # radius = (x1-x0)/10
     # for point in points:
     #     for p in point4s:
-    #         if(isNearbyPoint(p,radius,point)):
+    #         if(isNearbyPoint(p, radius, point)):
     #             tarPoints.append(point)
 
-    # if(len(tarPoints)>0):
+    # if(len(tarPoints) > 0):
     #     rect = cv2.boundingRect(np.array(tarPoints))
     # else:
     #     rect = cv2.boundingRect(np.array(points))
 
     rect = cv2.boundingRect(np.array(points))
-    return [rect[0]+x0, rect[1]+y0, rect[2], rect[3]]
+    return [rect[0]+x0, rect[1]+y0, rect[2]-1, rect[3]-1]
 
 # 框校准，image 是图片的三维数组
+
+
 def calcRectByImage(image, boxs=[], padding=5, areaThreshold=900):
     imgHeight, imgWidth, chanel = image.shape
     borderType = cv2.BORDER_CONSTANT
@@ -112,18 +116,23 @@ def calcRectByImage(image, boxs=[], padding=5, areaThreshold=900):
                 results.append([label, x, y, w, h])
             else:
                 results.append(box)
+            # results.append([label, x, y, w, h])
         else:
             results.append(box)
 
     return results
 
 # 图片框校准,image 是二进制数组
+
+
 def calcRectByImageBytes(image, boxs=[], padding=5, areaThreshold=900):
     arr = np.asarray(bytearray(image), dtype="uint8")
     img = cv2.imdecode(arr, cv2.IMREAD_COLOR)
     return calcRectByImage(img, boxs, padding, areaThreshold)
 
 # 图片框校准,source 是图片文件路径
+
+
 def calcRectByImagePath(source, boxs=[], padding=5, areaThreshold=900):
     img = img0 = cv2.imread(source)
     return calcRectByImage(img, boxs, padding, areaThreshold)
